﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;

namespace PdfToHtml {
    public class HtmlBuilder {
        private StringBuilder html;
        private string indent;
        private string assetPath;
        private string assetUrl;

        public HtmlBuilder(string assetPath, string assetUrl) {
            html = new StringBuilder();
            indent = "";
            this.assetPath = assetPath;
            this.assetUrl = assetUrl;
        }

        private string ParseAttributes(Dictionary<string, object> style, string className, Dictionary<string, object> attributes) {
            string attrString = "";
            if (attributes != null) {
                foreach (var kv in attributes) {
                    attrString += " " + kv.Key + "=\"" + kv.Value + "\"";
                }
            }
            if (className != null) {
                attrString += " class=\"" + className + "\"";
            }
            if (style != null) {
                string styleString = " ";
                foreach (var kv in style) {
                    styleString += " " + kv.Key + ": " + kv.Value + ";";
                }
                if (styleString.Length > 1) {
                    attrString += " style=\"" + styleString.Substring(1) + "\"";
                }
            }
            return attrString;
        }

        public void Open(string type, string className = null, Dictionary<string, object> style = null, Dictionary<string, object> attributes = null) {
            html.AppendLine(indent + "<" + type + ParseAttributes(style, className, attributes) + ">");
            indent += " ";
        }

        public void Close(string type) {
            if (indent.Length < 1) {
                throw new InvalidOperationException("Html is already closed");
            }
            indent = indent.Substring(0, indent.Length - 1);
            html.AppendLine(indent + "</" + type + ">");
        }

        public void Raw(string content) {
            html.AppendLine(indent + content);
        }

        public void MultiLineRaw(string content, string indentOverride = null) {
            indentOverride = indentOverride ?? indent;
            foreach (string line in content.Split(new[] {"\r\n", "\r", "\n"}, StringSplitOptions.None)) {
                html.AppendLine(indentOverride + line);
            }
        }

        public void Inline(string type, string className = null, string content = null, Dictionary<string, object> style = null, Dictionary<string, object> attributes = null) {
            if (content == null) {
                html.AppendLine(indent + "<" + type + ParseAttributes(style, className, attributes) + "/>");
            } else {
                html.AppendLine(indent + "<" + type + ParseAttributes(style, className, attributes) + ">" + content + "</" + type + ">");
            }
        }
        
        public string AssetUrl(string asset) {
            return Path.Combine(assetUrl, asset).Replace('\\', '/');
        }
        
        public string AssetPath(string asset) {
            Directory.CreateDirectory(assetPath);
            return Path.Combine(assetPath, asset);
        }


        public override string ToString() {
            return html.ToString();
        }
    }
}