﻿using System;
using SolidFramework.Model.Plumbing;

namespace PdfToHtml.Models {
    class BaseModel {
        public ParentModel Parent { get; private set; }
        public PageModel Page { get; protected set; }
        public FileModel File { get; private set; }
        public int Index { get; private set; }
        public int ZIndex { get; set; }

        public double Left { get; set; }
        public double Top { get; set; }
        public double Width { get; set; }
        public double Height { get; set; }
        public double TextRotatation { get; set; }

        public BaseModel(ParentModel parent) {
            TextRotatation = 0;
            Parent = parent;
            Left = 0;
            Top = 0;
            Width = 0;
            Height = 0;
            if (this is FileModel) {
                Page = null;
                File = (FileModel)this;
            } else if (this is PageModel) {
                Page = (PageModel)this;
                File = (FileModel)Parent;
            } else if ((Parent == null) || (Parent.Page == null)) {
                throw new InvalidOperationException("Model created without a page!");
            } else { 
                Page = Parent.Page;
                File = Parent.File;
            }
            if (Parent != null) {
                TextRotatation = Parent.TextRotatation;
                Index = Parent.Contents.Count + 1;
            }
        }

        protected bool GetLayoutInfo(SolidObject model) {
            var layout = File.FindLayoutObject(model.GetID());
            if (layout != null) {
                var bounds = layout.Bounds;
                var size = layout.Size;
                Left = bounds.Left;
                Top = bounds.Top;
                Width = size.Width;
                Height = size.Height;
                if (!double.IsNaN(Left) && !double.IsNaN(Top) && !double.IsNaN(Width) && !double.IsNaN(Height)) {
                    return true;
                }
            }
            Left = Top = Width = Height = 0;
            return false;
        }

        public virtual void SaveHtml(HtmlBuilder html, double x, double y) {
        }

        public string Rem(double value, string format) {
            format = (format ?? "0.0");
            format += format.Contains(".")? "0" : ".0";
            return (value / File.RemSize).ToString(format) + "rem";
        }
        
        public string Pt(double value, string format=null) {
            if (File.UseRelativeScale) {
                return Rem(value, format);
            }
            value *= File.Scale;
            format = (format ?? "0.0");
            return value.ToString(format) + "pt";
        }
    }
}