﻿using System;
using System.Collections.Generic;
using SolidFramework.Model.Plumbing;

namespace PdfToHtml.Models {
    
    class ParentModel: BaseModel {
        public List<BaseModel> Contents { get; private set; }
        
        protected ParentModel(ParentModel parent) : base(parent) {
            Contents = new List<BaseModel>();
        }

        public void AddContent(SolidObject obj) {
            var textbox = obj as TextBox;
            if (textbox != null) {
                Contents.Add(new TextBoxModel(this, textbox));
            } else if (obj is Table) {
                int zindex = ZIndex;
                ZIndex = Math.Max(-19, ZIndex);
                var table = new TableModel(this, (Table)obj);
                Contents.Add(table);
                ZIndex = zindex;
            } else if (obj is Paragraph) {
                int zindex = ZIndex;
                ZIndex = Math.Max(-19, ZIndex);
                Contents.Add(new ParagraphModel(this, (Paragraph)obj));
                ZIndex = zindex;
            } else if (obj is ImageShape) {
                Contents.Add(new ImageModel(this, (ImageShape)obj));
            } else if (obj is Group) {
                Contents.Add(new ShapeGroupModel(this, (Group)obj));
            } else if (obj is Graphic) {
                Contents.Add(new GraphicModel(this, (Graphic)obj));
            } else if (obj is TOC) {
                throw new InvalidOperationException("Unexpected behaviour: Encountered TOC outside of a Section!");
            }
        }
    }
}
