﻿using System;
using System.Collections.Generic;
using System.Drawing;
using SolidFramework.Model.Plumbing;

namespace PdfToHtml.Models {
    sealed class TableOfContentsModel: ParentModel {
        public TOC Model { get; private set; }

        public TableOfContentsModel(ParentModel parent, TOC model) : base(parent) {
            ZIndex = Parent.ZIndex;
            Model = model;
        }

        public void FinishedLoadingContents() {
            PointF min = new PointF(), max = new PointF();
            ZIndex = 110;
            Left = min.X;
            Top = min.Y;
            Width = Math.Max(max.X - min.X, 10);
            Height = Math.Max(max.Y - min.Y, 10);
        }

        public override void SaveHtml(HtmlBuilder html, double x, double y) {
            SaveHtml(Page, html, x, y);
        }

        public void SaveHtml(PageModel page, HtmlBuilder html, double x, double y) {
            html.Open("div", "toc");
            foreach (var child in Contents) {
                if (child.Page == page) {
                    child.SaveHtml(html, x, y);
                }
            }
            html.Close("div");
        }

        private List<SolidObject> remainingContents;
        public bool AddItemsToLayoutPage(PageModel page) {
            if (remainingContents == null) {
                remainingContents = new List<SolidObject>();
                foreach (var obj in Model) {
                    remainingContents.Add(obj);
                }
            }
            if (page != Page) {
                page.ExtraneousTOCs.Add(this);
            }
            int i = 0;
            while (i < remainingContents.Count) {
                int pageNumber = File.GetPageNumberFor(remainingContents[i], 0);
                if (pageNumber <= page.Index) {
                    i += 1;
                } else {
                    break;
                }
            }
            var originalPage = Page;
            Page = page; // let the children think they are on the current page
            while (i > 0) {
                var obj = remainingContents[0];
                remainingContents.RemoveAt(0);
                AddContent(obj);
                i -= 1;
            }
            Page = originalPage;
            return remainingContents.Count < 1;
        }
    }
}