﻿using System;
using System.Diagnostics;
using System.IO;
using System.Threading;
using PdfToHtml.Models;

namespace PdfToHtml {
    class Program {
        const bool ExactMode = true;
        const string LicensePath = @"C:\PathToLicense\license.xml";

        static void Main(string[] args) {
            SolidFramework.License.Import(LicensePath);
            if (args.Length < 1) {
                Console.WriteLine("Usage: PdfToHtml filename");
                return;
            }
            string filename = args[0];
            if (File.Exists(filename)) {
                var model = new FileModel(filename, ExactMode);
                string path = Path.GetDirectoryName(filename);
                filename = Path.GetFileNameWithoutExtension(filename);
                string outputFile = Path.Combine(path, filename + ".html");
                string outputFolder = Path.Combine(path, filename + "-content");
                model.SaveHtml(outputFile, outputFolder, "./" + filename + "-content");
                Console.WriteLine("Conversion complete");
            } else {
                Console.WriteLine("File not found");
            }
        }

        static void RoundTrip(string pdfPath) {
            string path = Path.GetDirectoryName(pdfPath);
            string filename = Path.GetFileNameWithoutExtension(pdfPath);
            for (int i = 0; i < 5; i++) {
                if (i > 0) {
                    pdfPath = Path.Combine(path, filename + "-" + i + ".pdf");
                    Process.Start(Path.ChangeExtension(pdfPath, "html"));
                }
                while (!File.Exists(pdfPath)) {
                    if (i == 0) { throw new IOException("File not found " + pdfPath); }
                    Thread.Sleep(1000);
                }
                var model = new FileModel(pdfPath, ExactMode);
                string outputFile = Path.Combine(path, filename + "-" + (i+1) + ".html");
                string outputFolder = Path.Combine(path, filename + "-content");
                model.SaveHtml(outputFile, outputFolder, "./" + filename + "-content");
                string text = File.ReadAllText(outputFile);
                string targetLine = "window.onload = function() {";
                text = text.Replace(targetLine, targetLine + "window.print();");
                File.WriteAllText(outputFile, text);
                Console.WriteLine("Conversion #" + (i+1) + " complete");
            }
        }
    }
}
